==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_it_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=it_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'Aggiungi un documento',
	'bouton_ajouter_image' => 'Aggiungi un’immagine',
	'bouton_ajouter_image_document' => 'Aggiungi un’immagine o un documento',

	// D
	'double_clic_inserer_doc' => 'Doppio clic qui per inserire la scorciatoia nel testo',

	// E
	'entree_dimensions' => 'Dimensioni:',
	'entree_titre_document' => 'Titolo del documento:',
	'entree_titre_image' => 'Titolo dell’immagine:',

	// I
	'image_tourner_180' => 'Ruota 180°',
	'image_tourner_droite' => 'Ruota 90° a destra',
	'image_tourner_gauche' => 'Ruota 90° a sinistra',
	'info_document' => 'Documento',
	'info_document_indisponible' => 'Questo documento non è disponibile',
	'info_documents' => 'Documenti',
	'info_inclusion_directe' => 'Inclusione diretta:',
	'info_inclusion_vignette' => 'Inclusione dell’immagine:',
	'info_installer_tous_documents' => 'Installare tutti i documenti',
	'info_logo_max_taille' => 'I logo devono obbligatoriamente avere una dimensione inferiore a @maxi@ (questo file è di @actuel@).',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Mettere in repertorio un documento su Internet:',
	'info_telecharger' => 'Upload dal tuo computer:',
	'item_autoriser_selectionner_date_en_ligne' => 'Permetti di modificare la data di ogni documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La data dei documenti è quella in cui sono stati aggiunti al sito.',

	// T
	'texte_documents_joints' => 'È possibile autorizzare l’aggiunta di documenti (file di testo, fogli elettronici, immagini, file multimediali, ecc.) agli articoli e/o alle rubriche. Questi file possono poi essere richiamati nel testo dell’articolo, o visualizzati separatamente.', # MODIF
	'texte_documents_joints_2' => 'Questa impostazione non impedisce l’inserimento diretto di immagini negli articoli.', # MODIF
	'titre_documents_joints' => 'Documenti allegati',
	'tout_dossier_upload' => 'Tutta la cartella @upload@',

	// U
	'upload_fichier_zip' => 'File ZIP',
	'upload_fichier_zip_texte' => 'Il file proposto è un file ZIP.',
	'upload_fichier_zip_texte2' => 'Questo file può essere:',
	'upload_limit' => 'Questo file è troppo grande per il server; la dimensione massima consentita per gli <i>upload</i> è di @max@.',
	'upload_zip_conserver' => 'Conserva l’archivio al termine dell’estrazione', # MODIF
	'upload_zip_decompacter' => 'decompresso e ogni elemento installato nel sito. I file che saranno installati nel sito sono:',
	'upload_zip_telquel' => 'installato così com’è in quanto archivio compresso Zip;',
	'upload_zip_titrer' => 'Dare i titoli in base al nome dei file'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_it_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=it_fem
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'Aggiungi un documento',
	'bouton_ajouter_image' => 'Aggiungi un’immagine',
	'bouton_ajouter_image_document' => 'Aggiungi un’immagine o un documento',

	// D
	'double_clic_inserer_doc' => 'Doppio clic qui per inserire la scorciatoia nel testo',

	// E
	'entree_dimensions' => 'Dimensioni:',
	'entree_titre_document' => 'Titolo del documento:',
	'entree_titre_image' => 'Titolo dell’immagine:',

	// I
	'image_tourner_180' => 'Ruota 180°',
	'image_tourner_droite' => 'Ruota 90° a destra',
	'image_tourner_gauche' => 'Ruota 90° a sinistra',
	'info_document' => 'Documento',
	'info_document_indisponible' => 'Questo documento non è disponibile',
	'info_documents' => 'Documenti',
	'info_inclusion_directe' => 'Inclusione diretta:',
	'info_inclusion_vignette' => 'Inclusione dell’immagine:',
	'info_installer_tous_documents' => 'Installare tutti i documenti',
	'info_logo_max_taille' => 'I logo devono obbligatoriamente avere una dimensione inferiore a @maxi@ (questo file è di @actuel@).',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Mettere in repertorio un documento su Internet:',
	'info_telecharger' => 'Upload dal tuo computer:',
	'item_autoriser_selectionner_date_en_ligne' => 'Permetti di modificare la data di ogni documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La data dei documenti è quella in cui sono stati aggiunti al sito.',

	// T
	'texte_documents_joints' => 'È possibile autorizzare l’aggiunta di documenti (file di testo, fogli elettronici, immagini, file multimediali, ecc.) agli articoli e/o alle rubriche. Questi file possono poi essere richiamati nel testo dell’articolo, o visualizzati separatamente.', # MODIF
	'texte_documents_joints_2' => 'Questa impostazione non impedisce l’inserimento diretto di immagini negli articoli.', # MODIF
	'titre_documents_joints' => 'Documenti allegati',
	'tout_dossier_upload' => 'Tutta la cartella @upload@',

	// U
	'upload_fichier_zip' => 'File ZIP',
	'upload_fichier_zip_texte' => 'Il file proposto è un file ZIP.',
	'upload_fichier_zip_texte2' => 'Questo file può essere:',
	'upload_limit' => 'Questo file è troppo grande per il server; la dimensione massima consentita per gli <i>upload</i> è di @max@.',
	'upload_zip_conserver' => 'Conserva l’archivio al termine dell’estrazione', # MODIF
	'upload_zip_decompacter' => 'decompresso e ogni elemento installato nel sito. I file che saranno installati nel sito sono:',
	'upload_zip_telquel' => 'installato così com’è in quanto archivio compresso Zip;',
	'upload_zip_titrer' => 'Dare i titoli in base al nome dei file',
];
